@@ -175,12 +175,13 @@ class Cli:
             conn.close()
 
     @staticmethod
-    def validate(model: str, offset: int = 0, limit: int = 100):
+    def validate(model: str, schema: str = "", offset: int = 0, limit: int = 100):
         """Extract a fhir model row and validates the Fhir resource
         against a Fhir server
 
         Args:
             model (str): should be a valid DBT Fhir model name such as `observation_heartrate`
+            schema (str): specify the search path
             offset (:obj:`int`, optional): set an offset to the query. Defaults to 0.
             limit (:obj:`int`, optional): a limit for the executed query. Defaults to 100.
         """
@@ -191,7 +192,7 @@ class Cli:
             user=POSTGRES_USER,
             password=POSTGRES_PASSWORD,
             cursor_factory=RealDictCursor,
-            options=f"-c search_path={FHIR_DBT_SCHEMA}",
+            options=f"-c search_path={schema or FHIR_DBT_SCHEMA}",
         )
         cursor = conn.cursor(name="curname")
         try:
