@@ -33,7 +33,7 @@ def resolve_references(line: str) -> str:
         UnknownDbtReferenceError: if a reference is specified but not found in the line
         EmptyDbtReferenceWarning: if dbt-ref doesn't specify at least one reference
     """
-    dbt_ref_pattern = r"(.*\b)(\s*--[ \t]*dbt-ref\((.*)\).*)"
+    dbt_ref_pattern = r"(.*)(\s*--[ \t]*dbt-ref\((.*)\).*)"
     result = re.search(dbt_ref_pattern, line)
     if not result:
         return line
